@@ -266,36 +266,33 @@ END					{ exit status }'
     done
 }
 
+__filter_journalctl_pmcd()
+{
+    grep " pmcd\\[" | sed -e 's/\.\.*done$//'
+}
+
+__journalctl_pmcd()
+{
+    if `which journalctl >/dev/null 2>&1`
+    then
+	journalctl -n 10 -u pmcd 2>/dev/null | __filter_journalctl_pmcd
+    elif `which systemd-journalctl >/dev/null 2>&1`
+    then
+	systemd-journalctl -q -n 100 2>/dev/null | __filter_journalctl_pmcd
+    fi
+}
+
 __pmda_restart_pmcd()
 {
     if [ -n "$PCP_SYSTEMDUNIT_DIR" -a -f $PCP_SYSTEMDUNIT_DIR/pmcd.service -a "$PCPQA_SYSTEMD" != no ]
     then
 	# smells like systemctl is the go ...
 	#
-	if `which journalctl >/dev/null 2>&1`
-	then
-	    journalctl -n 10 -u pmcd \
-	    | grep " pmcd\\[" \
-	    | sed -e 's/\.\.*done$//' >$tmp.journal.pre
-	elif `which systemd-journalctl >/dev/null 2>&1`
-	then
-	    systemd-journalctl -q -n 100 \
-	    | grep " pmcd\\[" \
-	    | sed -e 's/\.\.*done$//' >$tmp.journal.pre
-	fi
+	__journalctl_pmcd > $tmp.journal.pre
 	systemctl restart pmcd.service
         sleep 2
-	if `which journalctl >/dev/null 2>&1`
-	then
-	    journalctl -n 10 -u pmcd \
-	    | grep " pmcd\\["  \
-	    | sed -e 's/\.\.*done$//' >$tmp.journal.post
-	elif `which systemd-journalctl >/dev/null 2>&1`
-	then
-	    systemd-journalctl -q -n 100 \
-	    | grep " pmcd\\[" \
-	    | sed -e 's/\.\.*done$//' >$tmp.journal.post
-	fi
+	__journalctl_pmcd > $tmp.journal.post
+
 	# diff the pre and post journal lines to find those most recently
 	# added:
 	#	- lines beginning with a digit are ed(1) commands, ignore
@@ -798,8 +795,22 @@ _setup()
 	    perl -e 'use PCP::PMDA' >$tmp/out 2>&1
 	    if test $? -eq 0
 	    then
-		eval PCP_PERL_DOMAIN=1 perl "$perl_name" > "$perl_dom"
-		eval PCP_PERL_PMNS=1 perl "$perl_name" > "$perl_pmns"
+		if eval PCP_PERL_DOMAIN=1 perl "$perl_name" >"$perl_dom"
+		then
+		    :
+		else
+		    echo "Arrgh! failed to create $perl_dom from $perl_name"
+		    status=1
+		    exit
+		fi
+		if eval PCP_PERL_PMNS=1 perl "$perl_name" >"$perl_pmns"
+		then
+		    :
+		else
+		    echo "Arrgh! failed to create $perl_pmns from $perl_name"
+		    status=1
+		    exit
+		fi
 	    elif $dso_opt || $daemon_opt
 	    then
 		:	# we have an alternative, so continue on
@@ -842,8 +853,22 @@ _setup()
 	    __syntax=$?
 	    if test $__module -eq 0 -a $__syntax -eq 0
 	    then
-		eval PCP_PYTHON_DOMAIN=1 $python "$python_name" > "$python_dom"
-		eval PCP_PYTHON_PMNS=1 $python "$python_name" > "$python_pmns"
+		if eval PCP_PYTHON_DOMAIN=1 $python "$python_name" >"$python_dom"
+		then
+		    :
+		else
+		    echo "Arrgh! failed to create $python_dom from $python_name"
+		    status=1
+		    exit
+		fi
+		if eval PCP_PYTHON_PMNS=1 $python "$python_name" >"$python_pmns"
+		then
+		    :
+		else
+		    echo "Arrgh! failed to create $python_pmns from $python_name"
+		    status=1
+		    exit
+		fi
 	    elif $dso_opt || $daemon_opt
 	    then
 		:	# we have an alternative, so continue on
@@ -1374,7 +1399,7 @@ _remove()
 	for __n in $pmns_name
 	do
 	    $PCP_ECHO_PROG $PCP_ECHO_N "Check $__n metrics have gone away ... ""$PCP_ECHO_C"
-	    if pminfo -n $NAMESPACE -f $__n >$tmp/base 2>&1
+	    if PCP_DERIVED_CONFIG= pminfo -n $NAMESPACE -v -b 1000 $__n >$tmp/base 2>&1
 	    then
 		echo "Arrgh, something has gone wrong!"
 		cat $tmp/base
